@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 """
 test rex string formatting
 """
@@ -90,7 +105,7 @@ class TestFormatter(TestBase):
             def __format__(self, format_spec):
                 if format_spec == 'd':
                     return 'G(' + self.x + ')'
-                return object.__format__(self, format_spec)
+                return format(str(self), format_spec)
 
         # class that returns a bad type from __format__
         class H(object):
@@ -178,18 +193,6 @@ class TestFormatter(TestBase):
         self.assert_formatter_equal('{0!r:}', "'Hello'", 'Hello')
         self.assert_formatter_equal('{0!r}', 'F(Hello)', F('Hello'))
 
-        # test fallback to object.__format__
-        self.assert_formatter_equal('{0}', '{}', {})
-        self.assert_formatter_equal('{0}', '[]', [])
-        self.assert_formatter_equal('{0}', '[1]', [1])
-
-        if six.PY2:
-            # Classes without __format__ are not supported in Python 3
-            self.assert_formatter_equal('{0}', 'E(data)', E('data'))
-            self.assert_formatter_equal('{0:^10}', ' E(data)  ', E('data'))
-            self.assert_formatter_equal('{0:^10s}', ' E(data)  ', E('data'))
-            self.assert_formatter_equal('{0:>15s}', ' string is data', G('data'))
-
         self.assert_formatter_equal('{0:d}', 'G(data)', G('data'))
         self.assert_formatter_equal('{0!s}', 'string is data', G('data'))
 
@@ -295,19 +298,3 @@ class TestFormatter(TestBase):
 
 if __name__ == '__main__':
     unittest.main()
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
